<?php
class Elementor_WooCommerce_Gallery_Widget extends \Elementor\Widget_Base {

    public function get_name() {
        return 'woocommerce-gallery';
    }

    public function get_title() {
        return __('Galeria WooCommerce Premium', 'elementor-woocommerce-gallery');
    }

    public function get_icon() {
        return 'eicon-gallery-grid';
    }

    public function get_categories() {
        return ['woocommerce-elements'];
    }

    protected function register_controls() {
        // Seção de Conteúdo
        $this->start_controls_section(
            'content_section',
            [
                'label' => __('Configurações', 'elementor-woocommerce-gallery'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        // Controles para query de produtos
        $this->add_control(
            'products_query',
            [
                'label' => __('Query de Produtos', 'elementor-woocommerce-gallery'),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'options' => $this->get_product_categories(),
                'multiple' => true,
                'label_block' => true,
            ]
        );

        // Adicione mais controles de query conforme necessário

        $this->end_controls_section();

        // Seção de Estilo
        $this->start_controls_section(
            'style_section',
            [
                'label' => __('Estilo', 'elementor-woocommerce-gallery'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        // Controle para cor do preço
        $this->add_control(
            'price_color',
            [
                'label' => __('Cor do Preço', 'elementor-woocommerce-gallery'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ewg-product-price' => 'color: {{VALUE}}',
                ],
            ]
        );

        // Controle para texto do botão
        $this->add_control(
            'button_text',
            [
                'label' => __('Texto do Botão', 'elementor-woocommerce-gallery'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('Comprar Agora', 'elementor-woocommerce-gallery'),
            ]
        );

        // Controle para mostrar/ocultar botão
        $this->add_control(
            'show_button',
            [
                'label' => __('Mostrar Botão', 'elementor-woocommerce-gallery'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Sim', 'elementor-woocommerce-gallery'),
                'label_off' => __('Não', 'elementor-woocommerce-gallery'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        // Controle para posição do preço
        $this->add_control(
            'price_position',
            [
                'label' => __('Posição do Preço', 'elementor-woocommerce-gallery'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'above' => __('Acima do Título', 'elementor-woocommerce-gallery'),
                    'below' => __('Abaixo do Título', 'elementor-woocommerce-gallery'),
                ],
                'default' => 'below',
            ]
        );

        // Adicione mais controles de estilo...

        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        $args = [
            'post_type' => 'product',
            'posts_per_page' => -1,
            // Adicione mais parâmetros de query conforme necessário
        ];

        $products = new \WP_Query($args);

        if ($products->have_posts()) {
            echo '<div class="ewg-grid">';
            
            while ($products->have_posts()) {
                $products->the_post();
                global $product;
                
                echo '<div class="ewg-product">';
                echo '<div class="ewg-product-inner">';
                
                // Imagem do produto
                echo '<div class="ewg-product-image">';
                echo woocommerce_get_product_thumbnail('large');
                echo '</div>';
                
                // Posição do preço
                if ($settings['price_position'] === 'above') {
                    echo '<div class="ewg-product-price">' . $product->get_price_html() . '</div>';
                }
                
                // Título do produto
                echo '<h3 class="ewg-product-title">' . get_the_title() . '</h3>';
                
                // Posição do preço
                if ($settings['price_position'] === 'below') {
                    echo '<div class="ewg-product-price">' . $product->get_price_html() . '</div>';
                }
                
                // Botão
                if ($settings['show_button'] === 'yes') {
                    echo '<a href="' . $product->add_to_cart_url() . '" class="ewg-product-button">';
                    echo esc_html($settings['button_text']);
                    echo '</a>';
                }
                
                echo '</div></div>';
            }
            
            echo '</div>';
            wp_reset_postdata();
        }
    }

    private function get_product_categories() {
        // Função para obter categorias de produtos
        $categories = get_terms('product_cat');
        $options = [];
        
        foreach ($categories as $category) {
            $options[$category->slug] = $category->name;
        }
        
        return $options;
    }
}